<?php

use Illuminate\Support\Facades\App;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Route;
use Illuminate\Support\Facades\URL;
/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

if (App::environment('production')) {
    URL::forceScheme('https');
}

Auth::routes(['register' => false]);

Route::get('/', 'RouteController@home')->name('home');

Route::middleware(['auth'])->group(function () {
    Route::get('/user/rol', 'UserController@rol')->name('user.rol');
    Route::get('/user/grupo_de_compra', 'UserController@grupoDeCompra');
});

Route::middleware(['auth', 'role:barrio'])->group(function() {
    Route::get('/pedido', 'RouteController@main')->name('pedido');
    Route::get('/pedido/sesion', 'SessionController@fetch');
    Route::post('/pedido/sesion', 'SessionController@store');
});

Route::get('/admin/login', 'AdminController@show')->name('admin.login');

Route::middleware(['auth', 'role:admin_barrio'])->group(function () {
	Route::get('/admin', 'RouteController@main')->name('admin');

	Route::get('/admin/exportar-planillas-a-pdf/{gdc}', 'AdminController@exportarPedidosAPdf');
	Route::get('/admin/exportar-pedido-a-csv/{gdc}', 'AdminController@exportarPedidoACSV');
	Route::get('/admin/exportar-pedido-con-nucleos-a-csv/{gdc}', 'AdminController@exportarPedidoConNucleosACSV');
});

Route::get('/compras/login', 'ComprasController@show')->name('compras.login');

Route::middleware(['auth', 'role:comision'])->group( function() {
    Route::get('/compras', 'RouteController@main')->name('compras');
    Route::get('/compras/pedidos/descargar', 'ComprasController@descargarPedidos')->name('compras.pedidos.descargar');
    Route::get('/compras/pedidos/notas', 'ComprasController@descargarNotas')->name('compras.pedidos.descargar');
    Route::get('/compras/pedidos/pdf', 'ComprasController@pdf')->name('compras.pedidos.pdf');
    Route::get('/compras/canasta/ejemplo', 'ComprasController@descargarCanastaEjemplo')->name('compras.canasta.ejemplo');
    Route::post('/compras/canasta', 'ComprasController@cargarCanasta')->name('compras.canasta');
});
